@@ -160,6 +160,7 @@ pub struct SerializingSection<'a> {
     subsections: Vec<&'a str>,
     translations: Vec<TranslatedContent<'a>>,
     backlinks: Vec<BackLink<'a>>,
+    generate_feed: bool,
 }
 
 #[derive(Debug)]
@@ -218,6 +219,7 @@ impl<'a> SerializingSection<'a> {
             reading_time: section.reading_time,
             assets: &section.serialized_assets,
             lang: &section.lang,
+            generate_feed: section.meta.generate_feed,
             pages,
             subsections,
             translations,
