@@ -14,6 +14,7 @@ pub use filetime;
 pub use gh_emoji;
 pub use glob;
 pub use globset;
+pub use grass;
 pub use image;
 pub use lexical_sort;
 pub use minify_html;
@@ -27,7 +28,6 @@ pub use rayon;
 pub use regex;
 pub use relative_path;
 pub use reqwest;
-pub use sass_rs;
 pub use serde_json;
 pub use serde_yaml;
 pub use sha2;
