@@ -21,16 +21,20 @@
 // OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 // WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+use std::cell::Cell;
 use std::fs::read_dir;
+use std::future::IntoFuture;
 use std::net::{SocketAddrV4, TcpListener};
 use std::path::{Path, PathBuf, MAIN_SEPARATOR};
 use std::sync::mpsc::channel;
+use std::sync::Mutex;
 use std::thread;
 use std::time::{Duration, Instant};
 
-use hyper::header;
+use hyper::http::HeaderValue;
 use hyper::server::Server;
 use hyper::service::{make_service_fn, service_fn};
+use hyper::{body, header};
 use hyper::{Body, Method, Request, Response, StatusCode};
 use mime_guess::from_path as mimetype_from_path;
 use time::macros::format_description;
@@ -43,7 +47,7 @@ use libs::serde_json;
 use notify::{watcher, RecursiveMode, Watcher};
 use ws::{Message, Sender, WebSocket};
 
-use errors::{anyhow, Context, Result};
+use errors::{anyhow, Context, Error, Result};
 use pathdiff::diff_paths;
 use site::sass::compile_sass;
 use site::{Site, SITE_CONTENT};
@@ -75,6 +79,19 @@ static NOT_FOUND_TEXT: &[u8] = b"Not Found";
 // This is dist/livereload.min.js from the LiveReload.js v3.2.4 release
 const LIVE_RELOAD: &str = include_str!("livereload.js");
 
+static SERVE_ERROR: Mutex<Cell<Option<(&'static str, errors::Error)>>> =
+    Mutex::new(Cell::new(None));
+
+fn clear_serve_error() {
+    let _ = SERVE_ERROR.lock().map(|error| error.swap(&Cell::new(None)));
+}
+
+fn set_serve_error(msg: &'static str, e: errors::Error) {
+    if let Ok(serve_error) = SERVE_ERROR.lock() {
+        serve_error.swap(&Cell::new(Some((msg, e))));
+    }
+}
+
 async fn handle_request(req: Request<Body>, mut root: PathBuf) -> Result<Response<Body>> {
     let original_root = root.clone();
     let mut path = RelativePathBuf::new();
@@ -116,6 +133,14 @@ async fn handle_request(req: Request<Body>, mut root: PathBuf) -> Result<Respons
     // otherwise `PathBuf` will interpret it as an absolute path
     root.push(&decoded[1..]);
 
+    // Resolve the root + user supplied path into the absolute path
+    // this should hopefully remove any path traversals
+    // if we fail to resolve path, we should return 404
+    root = match tokio::fs::canonicalize(&root).await {
+        Ok(d) => d,
+        Err(_) => return Ok(not_found()),
+    };
+
     // Ensure we are only looking for things in our public folder
     if !root.starts_with(original_root) {
         return Ok(not_found());
@@ -148,6 +173,61 @@ async fn handle_request(req: Request<Body>, mut root: PathBuf) -> Result<Respons
         .unwrap())
 }
 
+/// Inserts build error message boxes into HTML responses when needed.
+async fn response_error_injector(
+    req: impl IntoFuture<Output = Result<Response<Body>>>,
+) -> Result<Response<Body>> {
+    let req = req.await;
+
+    // return req as-is if the request is Err(), not HTML, or if there are no error messages.
+    if req
+        .as_ref()
+        .map(|req| {
+            req.headers()
+                .get(header::CONTENT_TYPE)
+                .map(|val| val != &HeaderValue::from_static("text/html"))
+                .unwrap_or(true)
+        })
+        .unwrap_or(true)
+        || SERVE_ERROR.lock().unwrap().get_mut().is_none()
+    {
+        return req;
+    }
+
+    let mut req = req.unwrap();
+    let mut bytes = body::to_bytes(req.body_mut()).await.unwrap().to_vec();
+
+    if let Some((msg, error)) = SERVE_ERROR.lock().unwrap().get_mut() {
+        // Generate an error message similar to the CLI version in messages::unravel_errors.
+        let mut error_str = String::new();
+
+        if !msg.is_empty() {
+            error_str.push_str(&format!("Error: {msg}\n"));
+        }
+
+        error_str.push_str(&format!("Error: {error}\n"));
+
+        let mut cause = error.source();
+        while let Some(e) = cause {
+            error_str.push_str(&format!("Reason: {}\n", e));
+            cause = e.source();
+        }
+
+        // Push the error message (wrapped in an HTML dialog box) to the end of the HTML body.
+        //
+        // The message will be outside of <html> and <body> but web browsers are flexible enough
+        // that they will move it to the end of <body> at page load.
+        let html_error = format!(
+            r#"<div style="all:revert;position:fixed;display:flex;align-items:center;justify-content:center;background-color:rgb(0,0,0,0.5);top:0;right:0;bottom:0;left:0;"><div style="background-color:white;padding:0.5rem;border-radius:0.375rem;filter:drop-shadow(0,25px,25px,rgb(0,0,0/0.15));overflow-x:auto;"><p style="font-weight:700;color:black;font-size:1.25rem;margin:0;margin-bottom:0.5rem;">Zola Build Error:</p><pre style="padding:0.5rem;margin:0;border-radius:0.375rem;background-color:#363636;color:#CE4A2F;font-weight:700;">{error_str}</pre></div></div>"#
+        );
+        bytes.extend(html_error.as_bytes());
+
+        *req.body_mut() = Body::from(bytes);
+    }
+
+    Ok(req)
+}
+
 fn livereload_js() -> Response<Body> {
     Response::builder()
         .header(header::CONTENT_TYPE, "text/javascript")
@@ -213,6 +293,7 @@ fn not_found() -> Response<Body> {
 fn rebuild_done_handling(broadcaster: &Sender, res: Result<()>, reload_path: &str) {
     match res {
         Ok(_) => {
+            clear_serve_error();
             broadcaster
                 .send(format!(
                     r#"
@@ -228,7 +309,12 @@ fn rebuild_done_handling(broadcaster: &Sender, res: Result<()>, reload_path: &st
                 ))
                 .unwrap();
         }
-        Err(e) => messages::unravel_errors("Failed to build the site", &e),
+        Err(e) => {
+            let msg = "Failed to build the site";
+
+            messages::unravel_errors(msg, &e);
+            set_serve_error(msg, e);
+        }
     }
 }
 
@@ -238,6 +324,7 @@ fn create_new_site(
     interface: &str,
     interface_port: u16,
     output_dir: Option<&Path>,
+    force: bool,
     base_url: &str,
     config_file: &Path,
     include_drafts: bool,
@@ -268,6 +355,12 @@ fn create_new_site(
     site.enable_serve_mode();
     site.set_base_url(base_url);
     if let Some(output_dir) = output_dir {
+        if !force && output_dir.exists() {
+            return Err(Error::msg(format!(
+                "Directory '{}' already exists. Use --force to overwrite.",
+                output_dir.display(),
+            )));
+        }
         site.set_output_path(output_dir);
     }
     if include_drafts {
@@ -291,6 +384,7 @@ pub fn serve(
     interface: &str,
     interface_port: u16,
     output_dir: Option<&Path>,
+    force: bool,
     base_url: &str,
     config_file: &Path,
     open: bool,
@@ -305,6 +399,7 @@ pub fn serve(
         interface,
         interface_port,
         output_dir,
+        force,
         base_url,
         config_file,
         include_drafts,
@@ -384,7 +479,7 @@ pub fn serve(
 
                     async {
                         Ok::<_, hyper::Error>(service_fn(move |req| {
-                            handle_request(req, static_root.clone())
+                            response_error_injector(handle_request(req, static_root.clone()))
                         }))
                     }
                 });
@@ -475,6 +570,12 @@ pub fn serve(
     };
 
     let copy_static = |site: &Site, path: &Path, partial_path: &Path| {
+        // Do nothing if the file/dir is on the ignore list
+        if let Some(gs) = &site.config.ignored_static_globset {
+            if gs.is_match(partial_path) {
+                return;
+            }
+        }
         // Do nothing if the file/dir was deleted
         if !path.exists() {
             return;
@@ -507,6 +608,7 @@ pub fn serve(
         interface,
         interface_port,
         output_dir,
+        force,
         base_url,
         config_file,
         include_drafts,
@@ -514,11 +616,17 @@ pub fn serve(
         ws_port,
     ) {
         Ok((s, _)) => {
+            clear_serve_error();
             rebuild_done_handling(&broadcaster, Ok(()), "/x.js");
+
             Some(s)
         }
         Err(e) => {
-            messages::unravel_errors("Failed to build the site", &e);
+            let msg = "Failed to build the site";
+
+            messages::unravel_errors(msg, &e);
+            set_serve_error(msg, e);
+
             None
         }
     };
@@ -704,6 +812,7 @@ mod tests {
             Path::new("hello.html.__jb_bak___"),
             Path::new("hello.html~"),
             Path::new("#hello.html"),
+            Path::new(".index.md.kate-swp"),
         ];
 
         for t in test_cases {
